module val_coord

  use Math_Const
  use val_define
  use read_namelist
  use val_alloc

  implicit none

contains

subroutine val_coordinate()

  use Math_Const
  use val_define
  use read_namelist
  use val_alloc

  implicit none

  integer :: i

!-- 各座標径の設定

  rs=(/((rmin+(real(i-1))*dr),i=1,nr+3)/)
  zs=(/((zmin-(real(i-1))*dz),i=1,nz+3)/)    ! 圧力座標なので, 上ほど低い
  rv=(/((rmin+(real(i)-0.5)*dr),i=1,nr+3)/)
  zv=(/((zmin-(real(i)-0.5)*dr),i=1,nz+3)/)  ! 圧力座標なので, 上ほど低い
  theta=(/(((real(i-1))*2.0*pi/real(ntheta-1)),i=1,ntheta)/)

end subroutine

end module
